#!/bin/bash
#
# install libaunit package (normally in the chroot that just built it),
# and run test using it.

# usage
# cd libaunit-<version>/debian
# soversion=*; aliversion=*; debversion=*; sudo schroot ./test_installed.sh

# This re-installs the latest version.
sudo dpkg --install ../../libaunit${soversion}_1.03-${debversion}_i386.deb
sudo dpkg --install ../../libaunit${aliversion}-dev_1.03-${debversion}_i386.deb

# tmp is owned by root; we need write permission
sudo chmod o+w tmp

rm -rf tmp/aunit_test

gnatmake -p -Paunit_test
tmp/aunit_test/harness

# end of file
